@@ -1,4 +1,4 @@
-/* $Id: conf.c,v 1.2 2004/12/04 12:52:50 ichiro Exp $ */
+/* $Id: conf.c,v 1.3 2005/12/09 16:06:02 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -75,6 +75,8 @@ readconf(unsigned char *conf, struct config *cf)
 				{ cf->max_line = atoi(p + 9); continue; }
 			if (!strncmp(p, "LINE_REVERSE=", 13))
 				{ cf->line_reverse = atoi(p + 13); continue; }
+			if (!strncmp(p, "COOKIE_EXPIRE=", 14)) 
+				{ cf->cookie_expire = atoi(p + 14); continue; }
 			if (!strncmp(p, "WEB_USER=", 9))
 				{ strcpy(cf->auth_user, p + 9); continue; }
 			if (!strncmp(p, "WEB_PASS=", 9))
