@@ -1,4 +1,4 @@
-/* $Id: decode.c,v 1.3 2004/12/05 07:09:24 ichiro Exp $ */
+/* $Id: decode.c,v 1.4 2005/12/10 13:09:55 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -34,6 +34,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <regex.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <errno.h>
@@ -354,3 +355,48 @@ char * base64_decode(char *src)
 
 	return p;
 }
+
+char* href_conv(char* str) {
+	regex_t reg;
+	regmatch_t match;
+	int regsuccess; 
+
+	char *matched_str;
+	char *head_str;
+	char *tail_str;
+
+	int matched_str_len;
+	int head_str_len;
+	int tail_str_len;
+
+	regcomp(&reg,"http://[[:alnum:]./~?&%#_=-]+",REG_EXTENDED);
+	regsuccess = regexec(&reg, str, 1, &match,0);
+	regfree(&reg);
+
+	if(regsuccess == REG_NOMATCH) return str;
+
+	matched_str_len = match.rm_eo - match.rm_so;
+	head_str_len = match.rm_so;
+	tail_str_len = strlen(str) - match.rm_eo;
+
+	/* match str */
+	matched_str = (char*)malloc(matched_str_len + 1);
+	if(matched_str == NULL)
+	*matched_str = '\0';
+	strncat(matched_str, &str[match.rm_so], matched_str_len);
+
+	/* head str */
+	head_str = (char*)malloc(head_str_len + 1);
+	*head_str = '\0';
+	strncat(head_str, &str[0], head_str_len);
+
+	/* tail str */
+	tail_str = (char*)malloc(tail_str_len + 1);
+	*tail_str = '\0';
+	strncat(tail_str, &str[match.rm_eo], tail_str_len);
+
+	sprintf(str, "%s<a href=\"%s\">%s</a>%s",
+		head_str, matched_str, matched_str, tail_str);
+
+	return str;
+}
