@@ -1,4 +1,4 @@
-/* $Id: httpd.c,v 1.6 2005/12/09 16:06:02 ichiro Exp $ */
+/* $Id: httpd.c,v 1.11 2005/12/10 13:15:55 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -69,7 +69,7 @@ httpd(gpointer param)
 			printf("error: accepting a socket.\n");
 			exit (1);
 		}
-		usleep(100000);
+		usleep(10000);
 		httpd_proc(th2, s3);
 
 		close(s3);
@@ -144,7 +144,7 @@ void httpd_proc(struct tparam *th2, int socket)
 	/* Cookie Authentication */
 	if ((p = strstr(buf, "Cookie:")) != NULL) {
 		strcpy(base64, p + 8);
-#ifdef DEBUG
+#ifdef DEBUG2
 	printf("DEBUG: Cookie get.\n");
 #endif
 
@@ -157,7 +157,7 @@ void httpd_proc(struct tparam *th2, int socket)
 	}
 	/* Password Authentication */
 	if ((p = strstr(buf, "Authorization: Basic")) != NULL) {
-#ifdef DEBUG
+#ifdef DEBUG2
 	printf("DEBUG: Passwd get.\n");
 #endif
 		strcpy(base64, p + 21);
@@ -169,14 +169,14 @@ void httpd_proc(struct tparam *th2, int socket)
 	    (strcmp(cookie_pass, th2->auth_pass) == 0)) {
 		/* send header HTTP/1.1 200 OK */
 		send_msg(socket, http_header0);
-#ifdef DEBUG
+#ifdef DEBUG2
 	printf("DEBUG: Cookie Authentication done.\n");
 #endif
 	} else if ((strcmp(web_user, th2->auth_user) == 0) &&
 		   (strcmp(web_pass, th2->auth_pass) == 0)) {
 		/* send header HTTP/1.1 200 OK */
 		send_msg(socket, http_header0);
-#ifdef DEBUG
+#ifdef DEBUG2
 	printf("DEBUG: Passwd Authentication done.\n");
 #endif
 		/* send cookie info */
@@ -208,6 +208,12 @@ void httpd_proc(struct tparam *th2, int socket)
 #ifdef DEBUG
 		printf("status: POST Session\n");
 #endif
+		/* wait for flags clear */
+		while ((!th2->t_empty) || (th2->t_lock)) {
+			usleep(10000); /* 100ms */
+		}
+		th2->t_lock = 1;	/* now writing */
+
 		/* Get length of post data */
 		if ((s = strstr(buf, "Content-Length: ")))
 			post_length = atoi(s + 16);
@@ -228,22 +234,20 @@ void httpd_proc(struct tparam *th2, int socket)
 			sscanf(uri_addr + 1, "channel%d",
 				&post_ch_number);
 
-			while (th2->t_empty == 0) {
-				usleep(100000); /* 100ms */
-			}
-
 			/* channel decode (%hoge -> #hoge:*.jp) */
 			channel_decode(channel2,
 					th2->name[post_ch_number]);
 
 			/* transfer message to data buffer */
-			sprintf(th2->postdata[post_ch_number],
+			sprintf(th2->postdata,
 				":%s PRIVMSG %s :%s\r\n",
 				 th2->real_nickname, channel2,
 				 post_message2);
 
 			/* clear trans. empty flag */
 			th2->t_empty = 0;
+			th2->t_lock = 0;
+
 		} else if ((s = strstr(buf, "cname="))) {
 			/* clear buffer */
 			memset(cmd_cname, 0, sizeof(cmd_cname));        
@@ -297,14 +301,13 @@ void httpd_proc(struct tparam *th2, int socket)
 				goto command_start;
 			}
 
-			/* transfer message to data buffer */
-			strcpy(th2->postdata[post_ch_number],
-				post_message);
-			/* clear trans. empty flag */
-			th2->t_empty = 0;
+			/* transfer message */
+			strcpy(th2->postdata, post_message);
 		}
-		/* wait for post my message */
-		usleep(500000); /* 500ms */
+
+		/* clear trans lock and empty flag */
+		th2->t_empty = 0;
+		th2->t_lock = 0;
 	}	/* POST */
 
 	/* favicon.ico */
@@ -367,14 +370,18 @@ index_start:
 		}
 
 		/* print TOPIC */
-		sprintf(message, "$B$H$T$/(B :%s<br>",
-			th2->topic[number]);
-		send_msg(socket, message);
+		if (strlen(th2->topic[number]) > 0) {
+			sprintf(message, "$B$H$T$/(B :%s<br>",
+				th2->topic[number]);
+			send_msg(socket, message);
+		}
 
 		/* print NAMES */
-		sprintf(message, "member:%s<br>",
-			th2->member_names[number]);
-		send_msg(socket, message);
+		if (strlen(th2->member_names[number]) > 0) {
+			sprintf(message, "users:%s<br>",
+				th2->member_names[number]);
+			send_msg(socket, message);
+		}
 
 		/* print FORM */
 		sprintf(message,
@@ -467,22 +474,22 @@ int send_msg(int fd, char *msg)
 void print_command_page(int socket)
 {
 	send_msg(socket,
-		"<form action=\"/cmd\" method=\"post\">");
+	   "<form action=\"/cmd\" method=\"post\">");
 	send_msg(socket,
-		 "<input type=\"submit\" \
-			accesskey=\"1\" value=\"OK[1]\">");
+	   "<input type=\"submit\" \
+		accesskey=\"1\" value=\"OK[1]\">");
 	send_msg(socket,
-		"<a accesskey=\"8\" href=\"../\"> back[8]</a><hr>");
+	   "<a accesskey=\"8\" href=\"../\"> back[8]</a><hr>");
 	send_msg(socket,
-		"channel <input type=text name=\"cname\" size=\"10\">");
+	   "channel <input type=text name=\"cname\" size=\"10\">");
 	send_msg(socket,
-		"<br><input type=radio name=\"cmd\" value=\"join\">JOIN");
+	   "<br><input type=radio name=\"cmd\" value=\"join\">JOIN");
 	send_msg(socket,
-		"<br><input type=radio name=\"cmd\" value=\"part\">PART");
+	   "<br><input type=radio name=\"cmd\" value=\"part\">PART");
 	send_msg(socket,
-		"<br><input type=radio name=\"cmd\" value=\"list\">LIST");
+	   "<br><input type=radio name=\"cmd\" value=\"list\">USER update");
 	send_msg(socket,
-		"<br><input type=radio name=\"cmd\" value=\"topic\">TOPIC");
+	   "<br><input type=radio name=\"cmd\" value=\"topic\">TOPIC");
 	send_msg(socket,
-		"<input type=text name=\"toto\" size=\"7\"></form>");
+	   "<input type=text name=\"toto\" size=\"7\"></form>");
 }
