@@ -1,4 +1,4 @@
-/* $Id: keitai.c,v 1.7 2005/12/09 15:45:18 ichiro Exp $ */
+/* $Id: keitai.c,v 1.11 2005/12/10 13:09:55 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -52,13 +52,19 @@ keitai_start(struct tparam *th)
 	char a1[40], a2[40], a3[40], a4[IRC_MAX];
 	char *s;
 
-	/* skip NOTICE/PING messages */
-	if ((s = strstr(th->l_buff, "NOTICE")) ||
-		(s = strstr(th->l_buff, "PING")))
-			return (0);
 #ifdef DEBUG
 		printf("%s\r\n", th->l_buff);
 #endif
+	/* skip NOTICE messages */
+	if ((s = strstr(th->l_buff, "NOTICE"))) {
+	}
+
+	/* catch PING messages */
+	if ((s = strstr(th->l_buff, "PING"))) {
+		sscanf(th->l_buff, "PING :%[^\n]", a1);
+		ping_recv(th, a1);
+	}
+
 	/* catch NICK name */
 	if ((s = strstr(th->l_buff, "NICK"))) {
 		sscanf(th->l_buff, ":%*s NICK :%[^,]", a3);
@@ -130,8 +136,8 @@ int priv_recv(struct tparam *th)
 	struct tm* tm;
 	char id[40];
 	char channel[C_NAME], channel2[C_NAME];
-	char message[IRC_MAX];
-	char message2[IRC_MAX + 256]; /* include &lt,&gt charactor */
+	char message[IRC_MAX * 2];
+	char message2[IRC_MAX * 2]; /* include &lt,&gt charactor */
 
 	int n = 0;
 	int ch_number = 255; /* 255 means "not found" */
@@ -157,6 +163,8 @@ int priv_recv(struct tparam *th)
 	/* message; '<','>' ---> '&lt;','&gt;' */
         ltgt_encode(message2, message);
 
+	/* add href tag */
+	href_conv(message2);
 
 #ifdef DEBUG 
 	printf("%s | <%s> %s\n", channel2, id, message2);
@@ -200,16 +208,18 @@ int priv_recv(struct tparam *th)
 	}
 
 	/* add message with time into historical buffer */
-	if (strstr(th->real_nickname, id)) /* own messages */
+	if (strstr(th->real_nickname, id)) { /* own messages */
 		sprintf(th->
 			data[ch_number][th->history_count[ch_number]],
 			"%02d:%02d %s<  %s<br>",
 			tm->tm_hour, tm->tm_min,id, message2);
-	else
+		th->read_count[ch_number]++;
+	} else {
 		sprintf(th->
 			data[ch_number][th->history_count[ch_number]],
 			"%02d:%02d %s> %s<br>",
 			tm->tm_hour, tm->tm_min,id, message2);
+	}
 	th->history_count[ch_number]++;
 
 #ifdef DEBUG
@@ -244,7 +254,7 @@ int names_recv(struct tparam *th, char *channel, char *names)
 int topic_recv(struct tparam *th, char *user, char *channel, char *topic)
 {
 	int n = 0;
-	char buf[IRC_MAX];
+	char buf[IRC_MAX * 2];
 	char channel2[C_NAME];
 
 	memset(buf, 0, sizeof(buf));
@@ -260,6 +270,9 @@ int topic_recv(struct tparam *th, char *user, char *channel, char *topic)
 	/* '<','>' ---> '&lt;','&gt;' */
 	ltgt_encode(buf, topic);
 
+	/* add href tag */
+	href_conv(buf);
+
 	for (n = 0; n <= th->ch_count; n++) {
 		if (strstr(th->name[n], channel2))
 			sprintf(th->topic[n], " %s", buf);
@@ -357,6 +370,22 @@ int join_recv(struct tparam *th, char *channel)
 	printf("%s\r\n", th->l_buff);
 	printf("join channel name(%d) = %s\n", n, th->name[n]);
 #endif
-
 	return (n);
 }
+
+int ping_recv (struct tparam *th, char *server)
+{
+	char data[IRC_MAX];	
+
+	/* transfer message to data buffer */
+	sprintf(data, "PONG %s\r\n", server);
+
+	/* transfer message */
+	send_msg(th->socket_number, data);
+
+#ifdef DEBUG
+	printf("DEBUG PONG -> %s\n", server);
+#endif
+
+	return (0);
+}
