@@ -1,5 +1,4 @@
-/* $Id: kircd.h,v 1.5 2005/12/09 16:06:02 ichiro Exp $ */
-/* #define DEBUG */
+/* $Id: kircd.h,v 1.8 2005/12/10 13:09:55 ichiro Exp $ */
 #define DEBUG
 /*
  * Copyright (c) 2004
@@ -67,12 +66,14 @@ struct tparam {
 
 	char real_nickname[40];
 
+	/* recieve buffer */
 	int s_read;
 	int s_count;
 	int s_empty;	/* recieve buffer empty */
 	char *s_buff;
 	char *l_buff;
 	int s_lock;
+
 	int max_line;
 	int line_reverse;
 	int cookie_expire;
@@ -83,15 +84,15 @@ struct tparam {
 	int  read_count[CH_MAX];
 	char topic[CH_MAX][IRC_MAX];
 	char member_names[CH_MAX][IRC_MAX];
+
+	/* transfer buffer */
 	int  t_empty;	/* trans buffer empty */
-	char postdata[CH_MAX][IRC_MAX];
+	int  t_lock;	/* trans buffer writing */
+	char postdata[IRC_MAX];
 
 	/* auth (copy) */
 	char auth_user[40];
 	char auth_pass[40];
-
-	/* http */
-	int h_lock;
 };
 struct config {
 	char hostname[128];
@@ -133,3 +134,4 @@ extern int channel_encode(char *, char *);
 extern int channel_decode(char *, char *);
 extern int ltgt_encode(char *, char *);
 extern char * base64_decode(char *);
+extern char * href_conv(char *);
